@@ -20,7 +20,6 @@
 #include "button-widget.h"
 #include "launcher.h"
 #include "panel.h"
-#include "panel-addto.h"
 #include "panel-bindings.h"
 #include "panel-applet-frame.h"
 #include "panel-action-button.h"
@@ -245,7 +244,6 @@ panel_applet_get_callback (GList      *user_menu,
 void
 panel_applet_add_callback (AppletInfo          *info,
 			   const char          *callback_name,
-			   const char          *stock_item,
 			   const char          *menuitem_text,
 			   CallbackEnabledFunc  is_enabled_func)
 {
@@ -257,7 +255,6 @@ panel_applet_add_callback (AppletInfo          *info,
 
 	menu                  = g_new0 (AppletUserMenu, 1);
 	menu->name            = g_strdup (callback_name);
-	menu->stock_item      = g_strdup (stock_item);
 	menu->text            = g_strdup (menuitem_text);
 	menu->is_enabled_func = is_enabled_func;
 	menu->sensitive       = TRUE;
@@ -275,15 +272,7 @@ setup_an_item (AppletUserMenu *menu,
 	       GtkWidget      *submenu,
 	       int             is_submenu)
 {
-	GtkWidget *image = NULL;
-
-	menu->menuitem = gtk_image_menu_item_new_with_mnemonic (menu->text);
-	if (menu->stock_item && menu->stock_item [0]) {
-		image = gtk_image_new_from_stock (menu->stock_item,
-						  GTK_ICON_SIZE_MENU);
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu->menuitem),
-					       image);
-	}
+	menu->menuitem = gtk_menu_item_new_with_mnemonic (menu->text);
 	gtk_widget_show (menu->menuitem);
 
 	g_signal_connect (G_OBJECT (menu->menuitem), "destroy",
@@ -355,7 +344,6 @@ add_to_submenus (AppletInfo *info,
 	if (s_menu == NULL) {
 		s_menu = g_new0 (AppletUserMenu,1);
 		s_menu->name = g_strdup (t);
-		s_menu->stock_item = NULL;
 		s_menu->text = g_strdup (_("???"));
 		s_menu->sensitive = TRUE;
 		s_menu->info = info;
@@ -480,7 +468,6 @@ panel_applet_get_edit_menu (AppletInfo *info)
 {
 	GtkWidget   *menu;
 	GtkWidget   *menuitem;
-	GtkWidget   *image;
 	gboolean     movable;
 	gboolean     removable;
 
@@ -502,11 +489,7 @@ panel_applet_get_edit_menu (AppletInfo *info)
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_widget_set_sensitive (menuitem, movable);
 
-	menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Remove From Panel"));
-	image = gtk_image_new_from_stock (GTK_STOCK_REMOVE,
-					  GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem),
-				       image);
+	menuitem = gtk_menu_item_new_with_mnemonic (_("_Remove From Panel"));
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (applet_remove_callback), info);
 	gtk_widget_show (menuitem);
@@ -769,7 +752,6 @@ panel_applet_destroy (GtkWidget  *widget,
 		AppletUserMenu *umenu = l->data;
 
 		g_free (umenu->name);
-		g_free (umenu->stock_item);
 		g_free (umenu->text);
 
 		g_free (umenu);
@@ -995,7 +977,6 @@ panel_applet_register (GtkWidget       *applet,
 	gtk_widget_show (applet);
 
 	orientation_change (info, panel);
-	size_change (info, panel);
 	back_change (info, panel);
 
 	if (type != PANEL_OBJECT_APPLET)
